Stan Math Library: stan/math/prim/mat/prob/multi_normal_cholesky_rng.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
multi_normal_cholesky_rng.hpp File Reference
`#include <boost/random/normal_distribution.hpp>`
`#include <boost/random/variate_generator.hpp>`
`#include <stan/math/prim/scal/err/check_size_match.hpp>`
`#include <stan/math/prim/scal/err/check_finite.hpp>`
`#include <stan/math/prim/scal/err/check_not_nan.hpp>`
`#include <stan/math/prim/mat/fun/columns_dot_product.hpp>`
`#include <stan/math/prim/mat/fun/columns_dot_self.hpp>`
`#include <stan/math/prim/mat/fun/dot_product.hpp>`
`#include <stan/math/prim/mat/fun/dot_self.hpp>`
`#include <stan/math/prim/mat/fun/log.hpp>`
`#include <stan/math/prim/mat/fun/log_determinant.hpp>`
`#include <stan/math/prim/mat/fun/mdivide_left_spd.hpp>`
`#include <stan/math/prim/mat/fun/mdivide_left_tri_low.hpp>`
`#include <stan/math/prim/mat/fun/multiply.hpp>`
`#include <stan/math/prim/mat/fun/subtract.hpp>`
`#include <stan/math/prim/mat/fun/sum.hpp>`
`#include <stan/math/prim/scal/fun/constants.hpp>`
`#include <stan/math/prim/scal/meta/include_summand.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<class RNG >
Eigen::VectorXd | stan::math::multi_normal_cholesky_rng (const Eigen::Matrix< double, Eigen::Dynamic, 1 > &mu, const Eigen::Matrix< double, Eigen::Dynamic, Eigen::Dynamic > &S, RNG &rng)

[ Stan Home Page ] © 2011–2016, Stan Development Team.